@@ -4,7 +4,7 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,11 +13,11 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
+//
+// As a special exception to the GNU General Public License, permission is
+// granted for additional uses of the text contained in its release
 // of Common C++.
-// 
+//
 // The exception is that, if you link the Common C++ library with other
 // files to produce an executable, this does not by itself cause the
 // resulting executable to be covered by the GNU General Public License.
@@ -27,7 +27,7 @@
 // This exception does not however invalidate any other reasons why
 // the executable file might be covered by the GNU General Public License.
 //
-// This exception applies only to the code released under the 
+// This exception applies only to the code released under the
 // name Common C++.  If you copy code from other releases into a copy of
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
@@ -111,13 +111,11 @@ void MyThread::run(void)
 {
 	int rc;
 	char cbuf;
-	for(;;)
-	{
+	for(;;) {
 		rc = wait(&cbuf, 5000);
 		if(rc < 0)
 			cout << "timeout" << endl;
-		else
-		{
+		else {
 			cout << "char " << cbuf << endl;
 			Thread::sleep(50);
 		}
@@ -131,8 +129,7 @@ extern "C" int main(int argc, char **argv)
 	MyThread *thr = new MyThread();
 	thr->start();
 
-	for(;;)
-	{
+	for(;;) {
 		cin.getline(buffer, sizeof(buffer));
 		if(!strnicmp(buffer, "bye", 3))
 			break;
