@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -57,11 +57,10 @@
 
 #ifdef	CCXX_GNUTLS
 #include <gnutls/gnutls.h>
-typedef struct
-{
-        gnutls_session  session;
-        gnutls_certificate_credentials xcred;
-        int result;
+typedef struct {
+	gnutls_session  session;
+	gnutls_certificate_credentials xcred;
+	int result;
 }       SSL;
 #else
 #include <openssl/ssl.h>
