@@ -60,8 +60,10 @@
 
 #ifdef	__BORLANDC__
 #include <stdio.h>
+#include <stdlib.h>
 #else
 #include <cstdio>
+#include <cstdlib>
 #endif
 #include <sys/stat.h>
 #include <cerrno>
