@@ -46,9 +46,11 @@
 #ifdef	__BORLANDC__
 #include <stdarg.h>
 #include <stdio.h>
+#include <stdlib.h>
 #else
 #include <cstdarg>
 #include <cstdio>
+#include <cstdlib>
 #endif
 
 #ifdef	CCXX_NAMESPACES
