@@ -1,23 +1,23 @@
 // Copyright (C) 2002-2003 Chad C. Yates cyates@uidaho.edu
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
+//
+// As a special exception to the GNU General Public License, permission is
+// granted for additional uses of the text contained in its release
 // of Common C++.
-// 
+//
 // The exception is that, if you link the Common C++ library with other
 // files to produce an executable, this does not by itself cause the
 // resulting executable to be covered by the GNU General Public License.
@@ -27,13 +27,13 @@
 // This exception does not however invalidate any other reasons why
 // the executable file might be covered by the GNU General Public License.
 //
-// This exception applies only to the code released under the 
+// This exception applies only to the code released under the
 // name Common C++.  If you copy code from other releases into a copy of
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
+//
 // If you write modifications of your own for Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
@@ -51,7 +51,7 @@ void EngineTest::setUp()
   complexObject.strString2 = "String 2";
   complexObject.uninitializedNullPtr = NULL;  // initialized here instead of constructor to see if it will be unpersisted as a null (vs defaulting to null from the constructor)
   for(int i = 0; i < 10; i++)
-    complexObject.numbers.push_back(i);
+	complexObject.numbers.push_back(i);
   complexObject.strings.push_back("a");
   complexObject.strings.push_back("b");
   complexObject.strings.push_back("c");
@@ -70,29 +70,28 @@ void EngineTest::setUp()
   complexObject.subObjectPtr->strString = "SubStringPtr 1";
   complexObject.subObjectPtr->strString2 = "SubStringPtr 2";
   for(int j = 10; j < 20; j++)
-    complexObject.subObjectPtr->numbers.push_back(j);
+	complexObject.subObjectPtr->numbers.push_back(j);
 
   complexObject.subObjectRef.iInteger = 5;
   complexObject.subObjectRef.strString = "SubString2 1";
   complexObject.subObjectRef.strString2 = "SubString2 2";
   for(int k = 30; k < 35; k++)
-    complexObject.subObjectRef.numbers.push_back(k);
+	complexObject.subObjectRef.numbers.push_back(k);
 
   // make a std::deque of TestSub objects
-  for(int l = 0; l < 2; l++)
-  {
-    TestSub newSubObject;
-    newSubObject.iInteger = l;
-    char tmp[50];
-    sprintf(tmp, "test %d", l+1);
-    newSubObject.strString = tmp;
-    for(int k = 30; k < 35; k++)
-      newSubObject.numbers.push_back(k);
-    complexObject.subObjects.push_back(newSubObject);
+  for(int l = 0; l < 2; l++) {
+	TestSub newSubObject;
+	newSubObject.iInteger = l;
+	char tmp[50];
+	sprintf(tmp, "test %d", l+1);
+	newSubObject.strString = tmp;
+	for(int k = 30; k < 35; k++)
+	  newSubObject.numbers.push_back(k);
+	complexObject.subObjects.push_back(newSubObject);
   }
 }
 
-void EngineTest::tearDown() 
+void EngineTest::tearDown()
 {}
 
 void EngineTest::testPrimitives()
@@ -146,7 +145,7 @@ void EngineTest::testRawBinary()
 
   unsigned int binaryBuffer[BINARY_BUFFER_SIZE];
   for(i = 0; i < BINARY_BUFFER_SIZE; i++)
-    binaryBuffer[i] = i;
+	binaryBuffer[i] = i;
 
   outputEngine.writeBinary((const uint8*) binaryBuffer, sizeof(binaryBuffer));
   outputEngine.sync(); // flush Engine buffers before closing file
@@ -161,7 +160,7 @@ void EngineTest::testRawBinary()
   inputArchive.close();
 
   for(i = 0; i < BINARY_BUFFER_SIZE; i++)
-    CPPUNIT_ASSERT(binaryBuffer[i] == binaryBuffer2[i]);
+	CPPUNIT_ASSERT(binaryBuffer[i] == binaryBuffer2[i]);
 }
 
 void EngineTest::testSTLVector()
@@ -174,10 +173,9 @@ void EngineTest::testSTLVector()
 
   std::vector<int32> intVector;
   std::vector<int32>* pIntVector = new std::vector<int32>;
-  for(i = 0; i < STL_CONTAINER_SIZE; i++)
-  {
-    intVector.push_back(i);
-    pIntVector->push_back(i);
+  for(i = 0; i < STL_CONTAINER_SIZE; i++) {
+	intVector.push_back(i);
+	pIntVector->push_back(i);
   }
 
   outputEngine << intVector;
@@ -213,10 +211,9 @@ void EngineTest::testSTLDeque()
 
   std::deque<int32> intDeque;
   std::deque<int32>* pIntDeque = new std::deque<int32>;
-  for(i = 0; i < STL_CONTAINER_SIZE; i++)
-  {
-    intDeque.push_back(i);
-    pIntDeque->push_back(i);
+  for(i = 0; i < STL_CONTAINER_SIZE; i++) {
+	intDeque.push_back(i);
+	pIntDeque->push_back(i);
   }
 
   outputEngine << intDeque;
@@ -252,10 +249,9 @@ void EngineTest::testSTLMap()
 
   std::map<int32, int32> intMap;
   std::map<int32, int32>* pIntMap = new std::map<int32, int32>;
-  for(i = 0; i < STL_CONTAINER_SIZE; i++)
-  {
-    intMap.insert(std::pair<int32, int32>(i, i+10));
-    pIntMap->insert(std::pair<int32, int32>(i, i+11));
+  for(i = 0; i < STL_CONTAINER_SIZE; i++) {
+	intMap.insert(std::pair<int32, int32>(i, i+10));
+	pIntMap->insert(std::pair<int32, int32>(i, i+11));
   }
 
   outputEngine << intMap;
@@ -292,47 +288,47 @@ void EngineTest::testComplexObject()
 
   // Unpersist a new object structure into an uninitialized object
   {
-    Test* myObjPtr = NULL; // must initialize pointer or new persistence engine will think it is already allocated
-    std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
-    Engine inputEngine(inputArchive, ost::Engine::modeRead);
-    inputEngine >> myObjPtr;
-    inputArchive.close();
+	Test* myObjPtr = NULL; // must initialize pointer or new persistence engine will think it is already allocated
+	std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
+	Engine inputEngine(inputArchive, ost::Engine::modeRead);
+	inputEngine >> myObjPtr;
+	inputArchive.close();
 
-    CPPUNIT_ASSERT_MESSAGE("Unpersisted into unallocated pointer == Original", *myObjPtr == complexObject);
-    CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjPtr->nullPtr == NULL);
-    CPPUNIT_ASSERT_MESSAGE("uninitializedNullPtr is NULL", myObjPtr->uninitializedNullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("Unpersisted into unallocated pointer == Original", *myObjPtr == complexObject);
+	CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjPtr->nullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("uninitializedNullPtr is NULL", myObjPtr->uninitializedNullPtr == NULL);
 
-    myObjPtr->subObjectPtr->strString2 = "Changed SubStringPtr 1";
-    CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should always equal subObjectPtr2.strString2", myObjPtr->subObjectPtr->strString2 == myObjPtr->subObjectPtr2->strString2);
-    CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should now equal 'Changed SubStringPtr 1'", myObjPtr->subObjectPtr->strString2 == "Changed SubStringPtr 1");
-    CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should still equal subObjectPtr2.strString2", myObjPtr->subObjectPtr->strString2 == myObjPtr->subObjectPtr2->strString2);
+	myObjPtr->subObjectPtr->strString2 = "Changed SubStringPtr 1";
+	CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should always equal subObjectPtr2.strString2", myObjPtr->subObjectPtr->strString2 == myObjPtr->subObjectPtr2->strString2);
+	CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should now equal 'Changed SubStringPtr 1'", myObjPtr->subObjectPtr->strString2 == "Changed SubStringPtr 1");
+	CPPUNIT_ASSERT_MESSAGE("subObjectPtr.strString2 should still equal subObjectPtr2.strString2", myObjPtr->subObjectPtr->strString2 == myObjPtr->subObjectPtr2->strString2);
   }
 
   // Unpersist a new object structure into an instantiated class variable
   {
-    Test myObjInstance;
-    std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
-    Engine inputEngine(inputArchive, ost::Engine::modeRead);
-    inputEngine >> myObjInstance;
-    inputArchive.close();
+	Test myObjInstance;
+	std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
+	Engine inputEngine(inputArchive, ost::Engine::modeRead);
+	inputEngine >> myObjInstance;
+	inputArchive.close();
 
-    CPPUNIT_ASSERT_MESSAGE("Unpersisted into default constructed instance == Original", myObjInstance == complexObject);
-    CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjInstance.nullPtr == NULL);
-    CPPUNIT_ASSERT_MESSAGE("UninitializedNullPtr is NULL", myObjInstance.uninitializedNullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("Unpersisted into default constructed instance == Original", myObjInstance == complexObject);
+	CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjInstance.nullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("UninitializedNullPtr is NULL", myObjInstance.uninitializedNullPtr == NULL);
   }
 
   // Unpersist a new object structure into a pre-initialized pointer to an object
   {
-    Test* myObjAllocatedPtr = new Test;
-    std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
-    Engine inputEngine(inputArchive, ost::Engine::modeRead);
-    inputEngine >> myObjAllocatedPtr;
-    outputEngine.sync(); // flush Engine buffers before closing file
-    inputArchive.close();
+	Test* myObjAllocatedPtr = new Test;
+	std::fstream inputArchive("EngineComplexObjectTest.dat", std::ios::in);
+	Engine inputEngine(inputArchive, ost::Engine::modeRead);
+	inputEngine >> myObjAllocatedPtr;
+	outputEngine.sync(); // flush Engine buffers before closing file
+	inputArchive.close();
 
-    CPPUNIT_ASSERT_MESSAGE("Unpersisted into pre-allocated pointer", *myObjAllocatedPtr == complexObject);
-    CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjAllocatedPtr->nullPtr == NULL);
-    CPPUNIT_ASSERT_MESSAGE("uninitializedNullPtr is NULL", myObjAllocatedPtr->uninitializedNullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("Unpersisted into pre-allocated pointer", *myObjAllocatedPtr == complexObject);
+	CPPUNIT_ASSERT_MESSAGE("nullPtr is NULL", myObjAllocatedPtr->nullPtr == NULL);
+	CPPUNIT_ASSERT_MESSAGE("uninitializedNullPtr is NULL", myObjAllocatedPtr->uninitializedNullPtr == NULL);
   }
 }
 
@@ -343,14 +339,12 @@ void EngineTest::testModeExceptions()
   Engine outputEngine(outputArchive, ost::Engine::modeWrite);
 
   int32 test_Int32 = 0x01234567;
-  try
-  {
-    outputEngine << test_Int32;
-    //CPPUNIT_FAIL("Call to persist to an input stream should throw an exception");
+  try {
+	outputEngine << test_Int32;
+	//CPPUNIT_FAIL("Call to persist to an input stream should throw an exception");
   }
-  catch(Engine::Exception ex)
-  {    
-    CPPUNIT_ASSERT_MESSAGE(ex.getString(), true);
+  catch(Engine::Exception ex) {
+	CPPUNIT_ASSERT_MESSAGE(ex.getString(), true);
   }
 
   outputArchive.close();
