@@ -10,12 +10,11 @@ int main()
  {
  Foo *f = new Foo();
  f->start();
- 
+
  // Endless!? why?
- do
- {
+ do {
  Thread::sleep( 1000 );
  }
  while( f->isRunning() );
  }
- 
+
